@@ -55,21 +55,21 @@ test_padding (EggPadding padding, gsize block, gconstpointer input,
 	g_assert_cmpsize (n_output, ==, n_result);
 }
 
-DEFINE_TEST(zero_padding)
+TESTING_TEST(zero_padding)
 {
 	guchar padded[] = { 0x00, 0x00, 0x00, 0x00, 'T', 'E', 'S', 'T' };
 	gchar raw[] = "TEST";
 	test_padding (egg_padding_zero_pad, 8, raw, 4, padded, 8);
 }
 
-DEFINE_TEST(zero_padding_no_data)
+TESTING_TEST(zero_padding_no_data)
 {
 	guchar padded[] = { };
 	gchar raw[] = "";
 	test_padding (egg_padding_zero_pad, 8, raw, 0, padded, 0);
 }
 
-DEFINE_TEST(pkcs1_one_padding)
+TESTING_TEST(pkcs1_one_padding)
 {
 	guchar padded[] = { 0x00, 0x01, 0xFF, 0x00, 'T', 'E', 'S', 'T' };
 	gchar raw[] = "TEST";
@@ -77,7 +77,7 @@ DEFINE_TEST(pkcs1_one_padding)
 	test_padding (egg_padding_pkcs1_unpad_01, 8, padded, 8, raw, 4);
 }
 
-DEFINE_TEST(pkcs1_one_padding_no_data)
+TESTING_TEST(pkcs1_one_padding_no_data)
 {
 	guchar padded[] = { 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00 };
 	gchar raw[] = "";
@@ -85,7 +85,7 @@ DEFINE_TEST(pkcs1_one_padding_no_data)
 	test_padding (egg_padding_pkcs1_unpad_01, 8, padded, 8, raw, 0);
 }
 
-DEFINE_TEST(pkcs1_two_padding)
+TESTING_TEST(pkcs1_two_padding)
 {
 	guchar padded[] = { 0x00, 0x02, 0x77, 0x66, 0x55, 0x00, 'T', 'E', };
 	gchar raw[] = "TE";
@@ -111,31 +111,31 @@ DEFINE_TEST(pkcs1_two_padding)
 	g_assert (result[7] == 'E');
 }
 
-DEFINE_TEST(pkcs1_padding_invalid_prefix)
+TESTING_TEST(pkcs1_padding_invalid_prefix)
 {
 	guchar padded[] = { 0x01, 0x04, 0x04, 0x04 };
 	test_padding (egg_padding_pkcs1_unpad_01, 4, padded, 4, NULL, 0);
 }
 
-DEFINE_TEST(pkcs1_padding_invalid_type)
+TESTING_TEST(pkcs1_padding_invalid_type)
 {
 	guchar padded[] = { 0x00, 0x03, 0xFF, 0x00, 'T', 'E', 'S', 'T' };
 	test_padding (egg_padding_pkcs1_unpad_01, 8, padded, 8, NULL, 0);
 }
 
-DEFINE_TEST(pkcs1_padding_invalid_no_zero)
+TESTING_TEST(pkcs1_padding_invalid_no_zero)
 {
 	guchar padded[] = { 0x00, 0x01, 0xFF, 0xFF, 'T', 'E', 'S', 'T' };
 	test_padding (egg_padding_pkcs1_unpad_01, 8, padded, 8, NULL, 0);
 }
 
-DEFINE_TEST(pkcs1_padding_invalid_length)
+TESTING_TEST(pkcs1_padding_invalid_length)
 {
 	guchar padded[] = { 0x00, 0x01, 0xFF, 0xFF, 'T', 'E', 'S' };
 	test_padding (egg_padding_pkcs1_unpad_01, 8, padded, 7, NULL, 0);
 }
 
-DEFINE_TEST(pkcs7_padding)
+TESTING_TEST(pkcs7_padding)
 {
 	guchar padded[] = { 'T', 'E', 'S', 'T', 0x04, 0x04, 0x04, 0x04 };
 	gchar raw[] = "TEST";
@@ -144,7 +144,7 @@ DEFINE_TEST(pkcs7_padding)
 	test_padding (egg_padding_pkcs7_unpad, 8, padded, 8, raw, 4);
 }
 
-DEFINE_TEST(pkcs7_padding_equal_block)
+TESTING_TEST(pkcs7_padding_equal_block)
 {
 	guchar padded[] = { 'T', 'E', 'S', 'T', 'T', 'E', 'S', 'T', 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08 };
 	gchar raw[] = "TESTTEST";
@@ -153,7 +153,7 @@ DEFINE_TEST(pkcs7_padding_equal_block)
 	test_padding (egg_padding_pkcs7_unpad, 8, padded, 16, raw, 8);
 }
 
-DEFINE_TEST(pkcs7_padding_zero)
+TESTING_TEST(pkcs7_padding_zero)
 {
 	guchar padded[] = { 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08 };
 	gchar raw[] = "";
@@ -162,20 +162,20 @@ DEFINE_TEST(pkcs7_padding_zero)
 	test_padding (egg_padding_pkcs7_unpad, 8, padded, 8, raw, 0);
 }
 
-DEFINE_TEST(pkcs7_padding_invalid_zero)
+TESTING_TEST(pkcs7_padding_invalid_zero)
 {
 	guchar padded[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
 	test_padding (egg_padding_pkcs7_unpad, 8, padded, 8, NULL, 0);
 }
 
-DEFINE_TEST(pkcs7_padding_invalid_too_long)
+TESTING_TEST(pkcs7_padding_invalid_too_long)
 {
 	guchar padded[] = { 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08 };
 	test_padding (egg_padding_pkcs7_unpad, 4, padded, 8, NULL, 0);
 	test_padding (egg_padding_pkcs7_unpad, 4, padded, 4, NULL, 0);
 }
 
-DEFINE_TEST(pkcs7_padding_invalid_different)
+TESTING_TEST(pkcs7_padding_invalid_different)
 {
 	guchar padded[] = { 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08 };
 	test_padding (egg_padding_pkcs7_unpad, 8, padded, 8, NULL, 0);
